aboutsummaryrefslogtreecommitdiff
path: root/util-linux/nfsmount.c
diff options
context:
space:
mode:
Diffstat (limited to 'util-linux/nfsmount.c')
-rw-r--r--util-linux/nfsmount.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/util-linux/nfsmount.c b/util-linux/nfsmount.c
index 7b742cb5f..4ab415f0f 100644
--- a/util-linux/nfsmount.c
+++ b/util-linux/nfsmount.c
@@ -623,7 +623,7 @@ int nfsmount(const char *spec, const char *node, int *flags,
return retval;
}
/* create mount deamon client */
/* See if the nfs host = mount host. */
if (mounthost) {
if (mounthost[0] >= '0' && mounthost[0] <= '9') {
@@ -835,7 +835,7 @@ int nfsmount(const char *spec, const char *node, int *flags,
#endif
}
#ifdef NFS_MOUNT_DEBUG
- printf(_("using port %d for nfs deamon\n"), port);
+ printf(_("using port %d for nfs daemon\n"), port);
#endif
server_addr.sin_port = htons(port);
/*
@@ -623,7 +623,7 @@ int nfsmount(const char *spec, const char *node, int *flags,
return retval;
}
- /* create mount deamon client */
+ /* create mount daemon client */
/* See if the nfs host = mount host. */
if (mounthost) {